@@ -19,9 +19,117 @@ static char *cmd_output_ptr = 0;
 static int show_class = 0;
 int bar_hidden = 0;
 
+#define MENU_BASE -10
+#define MENU_ENTRIES 8
+
+static char *menu[] = {
+	"Menu [1/8]  Pass clicks on to clients?",
+	"Menu [2/8]  Resize windows when tiling?",
+	"Menu [3/8]  Retile when focus changes?",
+	"Menu [4/8]  Show class info on status bar?",
+	"Menu [5/8]  Current window should be floating?",
+	"Menu [6/8]  Current window should be a tool window?",
+	"Menu [7/8]  Current window should be sticky?",
+	"Menu [8/8]  Current window should be tiled?",
+};
+
+static int mlen[] = {
+	38,
+	39,
+	38,
+	42,
+	46,
+	51,
+	44,
+	43,
+};
+
+void do_menu (ScreenInfo *s)
+{
+	if ((bar_hidden >= 0) && (numhidden > 0) && (bar_hidden < numhidden))
+	{
+		bar_hidden = numhidden;
+		update_tbar ();
+	}
+	else switch (-bar_hidden + MENU_BASE)
+	{
+	case 0:
+		toggle_clickthru (s);
+		break;
+	case 1:
+		toggle_tile_resize (s);
+		break;
+	case 2:
+		toggle_skip_focus (s);
+		break;
+	case 3:
+		toggle_show_class ();
+		break;
+	case 4:
+		if (current && (current->screen == s))
+			toggle_isfloat (current);
+		break;
+	case 5:
+		if (current && (current->screen == s))
+			toggle_istool (current);
+		break;
+	case 6:
+		if (current && (current->screen == s))
+			toggle_issticky (current);
+		break;
+	case 7:
+		if (current && (current->screen == s))
+			toggle_isnotile (current);
+		break;
+	}
+}
+
+void prev_menu (void)
+{
+	if ((bar_hidden >= 0) && (numhidden > 0) && (bar_hidden < numhidden))
+	{
+		bar_hidden = numhidden;
+	}
+	else
+	{
+		bar_hidden++;
+
+		if ((bar_hidden > MENU_BASE) && (bar_hidden < numhidden))
+			bar_hidden = numhidden;
+		else if (bar_hidden > MENU_BASE)
+			bar_hidden = MENU_BASE - (MENU_ENTRIES - 1);
+	}
+
+	update_tbar ();
+}
+
+void next_menu (void)
+{
+	if ((bar_hidden >= 0) && (numhidden > 0) && (bar_hidden < numhidden))
+	{
+		bar_hidden = numhidden;
+	}
+	else
+	{
+		bar_hidden--;
+
+		if (bar_hidden > MENU_BASE)
+			bar_hidden = MENU_BASE;
+		else if (bar_hidden < (MENU_BASE - (MENU_ENTRIES - 1)))
+			bar_hidden = numhidden;
+	}
+
+	update_tbar ();
+}
+
 void show_hidden (void)
 {
-	if ((numhidden > 0) && (bar_hidden < numhidden))
+	if (bar_hidden < 0)
+	{
+		bar_hidden = numhidden;
+		update_tbar ();
+	}
+	else if ((bar_hidden >= 0) && (numhidden > 0) && (bar_hidden < numhidden))
 	{
 		Client *c = hiddenc[bar_hidden];
 
@@ -50,7 +158,9 @@ void next_hidden (void)
 {
 	bar_hidden++;
 
-	if (bar_hidden > numhidden)
+	if (bar_hidden < 0)
+		bar_hidden = numhidden;
+	else if (bar_hidden > numhidden)
 		bar_hidden = 0;
 
 	update_tbar ();
@@ -86,7 +196,7 @@ void update_cmd_output (void)
 
 void draw_tbar (ScreenInfo *s)
 {
-	int tlen, plen;
+	int tlen;
 	char sbar[256], tmp[256];
 
 	if (!s)
@@ -94,14 +204,18 @@ void draw_tbar (ScreenInfo *s)
 
 	XClearWindow(dpy, s->barwin);
 
-	if (bar_hidden < numhidden)
+	if (bar_hidden <= MENU_BASE)
+	{
+		XDrawString (dpy, s->barwin, s->gc, BAR_HEIGHT, BAR_TEXT_Y, menu[-bar_hidden + MENU_BASE], mlen[-bar_hidden + MENU_BASE]);
+	}
+	else if ((bar_hidden >= 0) && (bar_hidden < numhidden))
 	{
 		Client *c = hiddenc[bar_hidden];
 
 		if (c->screen == s)
 			sprintf (tmp, "Hidden [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
 		else
-			sprintf (tmp, " Other [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
+			sprintf (tmp, "Other Screen [%d/%d]  %s", bar_hidden + 1, numhidden, c->iconname ? c->iconname : c->label);
 
 		tlen = strlen (tmp);
 
@@ -122,7 +236,7 @@ void draw_tbar (ScreenInfo *s)
 
 	sbar[0] = '\0';
 
-	if (show_class && current && (current->screen == s) && (bar_hidden == numhidden))
+	if (show_class && current && (current->screen == s) && !((bar_hidden >= 0) && (bar_hidden < numhidden)))
 	{
 		strcat (sbar, "(");
 
@@ -149,8 +263,11 @@ void draw_tbar (ScreenInfo *s)
 		strcat (sbar, tmp);
 	}
 
-	strcat (sbar, prefs.dtname[s->num][s->desktop]);
-	strcat (sbar, "  ");
+	if (!((bar_hidden <= MENU_BASE) || ((bar_hidden >= 0) && (bar_hidden < numhidden))))
+	{
+		strcat (sbar, prefs.dtname[s->num][s->desktop]);
+		strcat (sbar, "  ");
+	}
 
 	tmp[0] = '[';
 	tmp[1] = s->notile_raised[s->desktop] ? 'U' : 'T';
@@ -164,17 +281,20 @@ void draw_tbar (ScreenInfo *s)
 
 	strcat (sbar, tmp);
 
-	if (cmd_output_ptr)
+	if (!((bar_hidden <= MENU_BASE) || ((bar_hidden >= 0) && (bar_hidden < numhidden))))
 	{
-		strcat (sbar, "  ");
-		strcat (sbar, cmd_output);
+		if (cmd_output_ptr)
+		{
+			strcat (sbar, "  ");
+			strcat (sbar, cmd_output);
+		}
 	}
 
 	tlen = strlen (sbar);
-	plen = XTextWidth (font, sbar, tlen);
 
 	if (tlen > 0)
 	{
+		int plen = XTextWidth (font, sbar, tlen);
 		XDrawString (dpy, s->barwin, s->gc, BAR_WIDTH(s) - plen - BAR_HEIGHT, BAR_TEXT_Y, sbar, tlen);
 	}
 }
