@@ -17,13 +17,10 @@ Client	*prev_current;
 
 void setactive(Client *c, int on)
 {
-	if (!c)
-		return;
-
-	if (c->parent == c->screen->root)
+	if (!c || (c->parent == c->screen->root))
 	{
-		fprintf(stderr, "larswm: bad parent in setactive; dumping core\n");
-		abort();
+		nofocus ();
+		return;
 	}
 
 	if (on)
