@@ -1,15 +1,15 @@
 /* Copyright (c) 1994-1996 David Hogan, see README for licence details */
 /* Many changes by Lars Bernhardsson. */
 
-#define VERSION		"larswm 7.0.8 by Lars Bernhardsson"
+#define VERSION		"larswm 7.0.13 by Lars Bernhardsson"
 
-#define BORDER		(prefs.border)
+#define BORDER		2
+#define TILE_PAD	1
 
 #define BAR_X(s)	0
-#define BAR_Y(s)	(DisplayHeight (dpy, (s)->num) - BAR_HEIGHT - 2)
-#define BAR_WIDTH(s)	(DisplayWidth (dpy, (s)->num) - 2)
+#define BAR_Y(s)	(DisplayHeight (dpy, (s)->num) - BAR_HEIGHT)
+#define BAR_WIDTH(s)	(DisplayWidth (dpy, (s)->num))
 #define BAR_HEIGHT	(font->ascent + font->descent)
-#define BAR_TOP(s)	(DisplayHeight (dpy, (s)->num) - BAR_HEIGHT - 2)
 #define BAR_TEXT_Y	(font->ascent)
 
 #define DEFSHELL	"/bin/sh"
@@ -105,7 +105,6 @@ struct ScreenInfo {
 	unsigned long	black;
 	unsigned long	white;
 	int		min_cmaps;
-	Cursor		arrow;
 	Cursor		place;
 	Cursor		sweep;
 	char		display[256];
@@ -125,11 +124,6 @@ struct ScreenInfo {
 };
 
 struct Prefs {
-	int		border;
-	int		tile_pad;
-
-	int		sticky_notile;
-
 	int		clickthru[MAXSCREENS][MAXDESKTOPS];
 	int		tile_resize[MAXSCREENS][MAXDESKTOPS];
 	int		skip_focus[MAXSCREENS][MAXDESKTOPS];
