@@ -33,7 +33,6 @@ void mainloop(int shape_event)
 			XAllowEvents (dpy, SyncPointer, ev.xbutton.time);
 			break;
 		case ButtonRelease:
-			XAllowEvents (dpy, SyncPointer, ev.xbutton.time);
 			break;
 		case MapRequest:
 			mapreq(&ev.xmaprequest);
@@ -83,6 +82,12 @@ void mainloop(int shape_event)
 				}
 			}
 			break;
+		case PropertyNotify:
+			property(&ev.xproperty);
+			break;
+		case Expose:
+			expose(&ev.xexpose);
+			break;
 		case CreateNotify:
 			newwindow(&ev.xcreatewindow);
 			break;
@@ -95,32 +100,17 @@ void mainloop(int shape_event)
 		case ColormapNotify:
 			cmap(&ev.xcolormap);
 			break;
-		case PropertyNotify:
-			property(&ev.xproperty);
-			break;
-		case EnterNotify:
-			enter(&ev.xcrossing);
-			break;
 		case ReparentNotify:
 			reparent(&ev.xreparent);
 			break;
-		case FocusIn:
-			focusin(&ev.xfocus);
-			break;
-		case Expose:
-			expose(&ev.xexpose);
-			break;
 		case SelectionNotify:
 			selection (&ev.xselection);
 			break;
-		case SelectionRequest:
-		case SelectionClear:
-		case CirculateRequest:
-		case MotionNotify:
-		case FocusOut:
-		case ConfigureNotify:
-		case MapNotify:
-		case MappingNotify:
+		case EnterNotify:
+			enter(&ev.xcrossing);
+			break;
+		case FocusIn:
+			focusin (&ev.xfocus);
 			break;
 		default:
 			if (shape && ev.type == shape_event)
@@ -528,47 +518,42 @@ void shapenotify(XShapeEvent *e)
 	setshape(c);
 }
 
-void enter(XCrossingEvent *e)
+void enter (XCrossingEvent *e)
 {
-	ScreenInfo *s;
-        Client *c;
-
-	if ((e->mode == NotifyNormal) &&
-	    (s = getscreen (e->window)) &&
-	    (current && (current->screen != s)))
-	{
-		revert_same (s);
-
-		if (!current)
-			revert_window (s);
+	Client *c;
 
+	if (e->mode != NotifyGrab || e->detail != NotifyNonlinearVirtual)
 		return;
+
+	c = getclient(e->window, 0);
+
+	if (c && c->parent && (c != current))
+	{
+		XMapRaised(dpy, c->parent);
+		active(c);
+	}
+	else
+	{
+		XSetInputFocus (dpy, e->window, RevertToPointerRoot, e->time);
 	}
-
-        if (e->mode != NotifyGrab || e->detail != NotifyNonlinearVirtual)
-                return;
-        c = getclient(e->window, 0);
-        if (c != 0 && c != current) {
-                raise_tbar (c->screen);
-                /* someone grabbed the pointer; make them current */
-                XMapRaised(dpy, c->parent);
-                top(c);
-                active(c);
-        }
 }
 
-void focusin(XFocusChangeEvent *e)
+void focusin (XFocusChangeEvent *e)
 {
-        Client *c;
+	Client *c;
 
-        if (e->detail != NotifyNonlinearVirtual)
-                return;
-        c = getclient(e->window, 0);
-        if (c != 0 && c->window == e->window && c != current) {
-                raise_tbar (c->screen);
-                /* someone grabbed keyboard or seized focus; make them current */
-                XMapRaised(dpy, c->parent);
-                top(c);
-                active(c);
-        }
+	if (e->detail != NotifyNonlinearVirtual)
+		return;
+
+	c = getclient(e->window, 0);
+
+	if (c && c->window && c->parent && (c->window == e->window) && (c != current))
+	{
+		XMapRaised(dpy, c->parent);
+		active(c);
+	}
+	else
+	{
+		XSetInputFocus (dpy, e->window, RevertToPointerRoot, CurrentTime);
+	}
 }
