@@ -21,9 +21,10 @@ void	clientmesg(XClientMessageEvent *);
 void	cmap(XColormapEvent *);
 void	property(XPropertyEvent *);
 void	shapenotify(XShapeEvent *);
-void	enter(XCrossingEvent *);
-void	focusin(XFocusChangeEvent *);
 void	reparent(XReparentEvent *);
+void	enter(XCrossingEvent *);
+void	focusin (XFocusChangeEvent *);
+
 
 /* manage.c */
 int 	manage(Client *, int);
@@ -139,6 +140,9 @@ void	initkeys(Client *);
 void	keyevent(XKeyEvent *);
 
 /* bar.c */
+void	do_menu (ScreenInfo *);
+void	prev_menu (void);
+void	next_menu (void);
 void	show_hidden (void);
 void	prev_hidden (void);
 void	next_hidden (void);
