@@ -39,105 +39,105 @@ void initkeys (Client *c)
 		int y;
 
 		/* only do this if there's a window to grab keys from */
-		if (prefs.prev_window_key && prefs.prev_window_mod)
+		if (prefs.prev_window_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.prev_window_key), prefs.prev_window_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.next_window_key && prefs.next_window_mod)
+		if (prefs.next_window_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.next_window_key), prefs.next_window_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.move_northwest_key && prefs.move_northwest_mod)
+		if (prefs.move_northwest_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_northwest_key), prefs.move_northwest_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_north_key && prefs.move_north_mod)
+		if (prefs.move_north_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_north_key), prefs.move_north_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_northeast_key && prefs.move_northeast_mod)
+		if (prefs.move_northeast_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_northeast_key), prefs.move_northeast_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_west_key && prefs.move_west_mod)
+		if (prefs.move_west_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_west_key), prefs.move_west_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_center_key && prefs.move_center_mod)
+		if (prefs.move_center_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_center_key), prefs.move_center_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_east_key && prefs.move_east_mod)
+		if (prefs.move_east_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_east_key), prefs.move_east_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_southwest_key && prefs.move_southwest_mod)
+		if (prefs.move_southwest_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_southwest_key), prefs.move_southwest_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_south_key && prefs.move_south_mod)
+		if (prefs.move_south_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_south_key), prefs.move_south_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-		if (prefs.move_southeast_key && prefs.move_southeast_mod)
+		if (prefs.move_southeast_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_southeast_key), prefs.move_southeast_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.move_up_key && prefs.move_up_mod)
+		if (prefs.move_up_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_up_key), prefs.move_up_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.move_down_key && prefs.move_down_mod)
+		if (prefs.move_down_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_down_key), prefs.move_down_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.move_left_key && prefs.move_left_mod)
+		if (prefs.move_left_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_left_key), prefs.move_left_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.move_right_key && prefs.move_right_mod)
+		if (prefs.move_right_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.move_right_key), prefs.move_right_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.grow_vert_key && prefs.grow_vert_mod)
+		if (prefs.grow_vert_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.grow_vert_key), prefs.grow_vert_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.shrink_vert_key && prefs.shrink_vert_mod)
+		if (prefs.shrink_vert_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.shrink_vert_key), prefs.shrink_vert_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.grow_horiz_key && prefs.grow_horiz_mod)
+		if (prefs.grow_horiz_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.grow_horiz_key), prefs.grow_horiz_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.shrink_horiz_key && prefs.shrink_horiz_mod)
+		if (prefs.shrink_horiz_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.shrink_horiz_key), prefs.shrink_horiz_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.grow_both_key && prefs.grow_both_mod)
+		if (prefs.grow_both_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.grow_both_key), prefs.grow_both_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.shrink_both_key && prefs.shrink_both_mod)
+		if (prefs.shrink_both_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.shrink_both_key), prefs.shrink_both_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.zoom_vert_key && prefs.zoom_vert_mod)
+		if (prefs.zoom_vert_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.zoom_vert_key), prefs.zoom_vert_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.zoom_horiz_key && prefs.zoom_horiz_mod)
+		if (prefs.zoom_horiz_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.zoom_horiz_key), prefs.zoom_horiz_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.zoom_full_key && prefs.zoom_full_mod)
+		if (prefs.zoom_full_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.zoom_full_key), prefs.zoom_full_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.hide_key && prefs.hide_mod)
+		if (prefs.hide_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.hide_key), prefs.hide_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.close_key && prefs.close_mod)
+		if (prefs.close_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.close_key), prefs.close_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
 		/* same as root window grab */
 		if (num_screens > 1)
 		{
-			if (prefs.prev_screen_key && prefs.prev_screen_mod)
+			if (prefs.prev_screen_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.prev_screen_key), prefs.prev_screen_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
-			if (prefs.next_screen_key && prefs.next_screen_mod)
+			if (prefs.next_screen_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.next_screen_key), prefs.next_screen_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 		}
 
-		if (prefs.prev_desktop_key && prefs.prev_desktop_mod)
+		if (prefs.prev_desktop_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.prev_desktop_key), prefs.prev_desktop_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.next_desktop_key && prefs.next_desktop_mod)
+		if (prefs.next_desktop_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.next_desktop_key), prefs.next_desktop_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.toggle_inc_key && prefs.toggle_inc_mod)
+		if (prefs.toggle_inc_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.toggle_inc_key), prefs.toggle_inc_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.raise_notile_key && prefs.raise_notile_mod)
+		if (prefs.raise_notile_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.raise_notile_key), prefs.raise_notile_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
-		if (prefs.unhide_key && prefs.unhide_mod)
+		if (prefs.unhide_key)
 			XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.unhide_key), prefs.unhide_mod, c->parent, True, GrabModeAsync, GrabModeAsync);
 
 		for (y = 0; y < prefs.desktops; y++)
-			if (prefs.goto_desktop_key[y] && prefs.goto_desktop_mod[y])
+			if (prefs.goto_desktop_key[y])
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.goto_desktop_key[y]), prefs.goto_desktop_mod[y], c->parent, True, GrabModeAsync, GrabModeAsync);
 
 		for (y = 0; y < MAXAPPS; y++)
-			if (prefs.application[y] && prefs.application_key[y] && prefs.application_mod[y])
+			if (prefs.application[y] && prefs.application_key[y])
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.application_key[y]), prefs.application_mod[y], c->parent, True, GrabModeAsync, GrabModeAsync);
 	}
 	else
@@ -152,32 +152,32 @@ void initkeys (Client *c)
 
 			if (num_screens > 1)
 			{
-				if (prefs.prev_screen_key && prefs.prev_screen_mod)
+				if (prefs.prev_screen_key)
 					XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.prev_screen_key), prefs.prev_screen_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
-				if (prefs.next_screen_key && prefs.next_screen_mod)
+				if (prefs.next_screen_key)
 					XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.next_screen_key), prefs.next_screen_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
 			}
 
-			if (prefs.prev_desktop_key && prefs.prev_desktop_mod)
+			if (prefs.prev_desktop_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.prev_desktop_key), prefs.prev_desktop_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
-			if (prefs.next_desktop_key && prefs.next_desktop_mod)
+			if (prefs.next_desktop_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.next_desktop_key), prefs.next_desktop_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
 
-			if (prefs.toggle_inc_key && prefs.toggle_inc_mod)
+			if (prefs.toggle_inc_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.toggle_inc_key), prefs.toggle_inc_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
 
-			if (prefs.raise_notile_key && prefs.raise_notile_mod)
+			if (prefs.raise_notile_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.raise_notile_key), prefs.raise_notile_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
 
-			if (prefs.unhide_key && prefs.unhide_mod)
+			if (prefs.unhide_key)
 				XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.unhide_key), prefs.unhide_mod, screens[i].root, True, GrabModeAsync, GrabModeAsync);
 
 			for (y = 0; y < prefs.desktops; y++)
-				if (prefs.goto_desktop_key[y] && prefs.goto_desktop_mod[y])
+				if (prefs.goto_desktop_key[y])
 					XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.goto_desktop_key[y]), prefs.goto_desktop_mod[y], screens[i].root, True, GrabModeAsync, GrabModeAsync);
 
 			for (y = 0; y < MAXAPPS; y++)
-				if (prefs.application[y] && prefs.application_key[y] && prefs.application_mod[y])
+				if (prefs.application[y] && prefs.application_key[y])
 					XGrabKey (dpy, XKeysymToKeycode (dpy, prefs.application_key[y]), prefs.application_mod[y], screens[i].root, True, GrabModeAsync, GrabModeAsync);
 		}
 	}
