@@ -39,13 +39,13 @@ Atom		wm_colormaps;
 void usage(void)
 {
 	fprintf(stderr, "%s\n", VERSION);
-	fprintf(stderr, "usage: larswm [-display display] [-f file] [-defaults] [-v] [message text | exit | restart]\n");
+	fprintf(stderr, "usage: larswm [-display display] [-f file] [-defaults] [-v]\n");
 	exit(1);
 }
 
 int main(int argc, char **argv)
 {
-	int i, do_exit, do_restart, do_message;
+	int i;
 	int shape_event, dummy;
 	char rcname[512];
 	char *display_string = "";
@@ -64,8 +64,6 @@ int main(int argc, char **argv)
 	}
 
 	myargv = argv;
-
-	do_exit = do_restart = do_message = 0;
 	font = 0;
 
 	for (i = 1; i < argc; i++)
@@ -84,32 +82,17 @@ int main(int argc, char **argv)
 			dump_prefs();
 			exit (0);
 		}
-		else if (strcmp(argv[i], "-v") == 0) {
+		else if (strcmp(argv[i], "-v") == 0)
+		{
 			fprintf(stderr, "%s\n", VERSION);
 			exit(0);
 		}
-		else if (strcmp(argv[i], "exit") == 0)
-		{
-			do_exit++;
-		}
-		else if (strcmp(argv[i], "restart") == 0)
-		{
-			do_restart++;
-		}
-		else if (strcmp(argv[i], "message") == 0)
-		{
-			msgtext = argv[++i];
-			do_message++;
-		}
 		else
 		{
 			usage();
 		}
 	}
 
-	if ((do_exit + do_restart + do_message) > 1)
-		usage();
-
 	shell = (char *)getenv("SHELL");
 
 	if (shell == NULL)
@@ -129,30 +112,6 @@ int main(int argc, char **argv)
 	bartext_larswm = XInternAtom(dpy, "LARSWM_BARTEXT", False);
 	selection_larswm = XInternAtom(dpy, "LARSWM_SELECTION", False);
 
-	if (do_exit)
-	{
-		sendcmessage(DefaultRootWindow(dpy), exit_larswm, 0L, 1);
-		XSync(dpy, False);
-		exit(0);
-	}
-
-	if (do_restart)
-	{
-		sendcmessage(DefaultRootWindow(dpy), restart_larswm, 0L, 1);
-		XSync(dpy, False);
-		exit(0);
-	}
-
-	if (do_message)
-	{
-		XTextProperty pr;
-
-		XStringListToTextProperty (&msgtext, 1, &pr);
-		XSetTextProperty (dpy, DefaultRootWindow (dpy), &pr, bartext_larswm);
-		XSync(dpy, False);
-		exit(0);
-	}
-
 	wm_state = XInternAtom(dpy, "WM_STATE", False);
 	wm_change_state = XInternAtom(dpy, "WM_CHANGE_STATE", False);
 	wm_protocols = XInternAtom(dpy, "WM_PROTOCOLS", False);
@@ -202,6 +161,7 @@ int main(int argc, char **argv)
 
 	initkeys(0);
 
+	XSync(dpy, False);
 	mainloop(shape_event);
 
 	exit (0);
@@ -212,7 +172,6 @@ void initscreen(ScreenInfo *s, int i)
 	char *ds, *colon, *dot1;
 	unsigned long mask;
 	XGCValues gv;
-	XSetWindowAttributes attr;
 	int t;
 
 	s->num = i;
@@ -293,18 +252,12 @@ void initscreen(ScreenInfo *s, int i)
 	}
 
 	s->gc = XCreateGC(dpy, s->root, mask, &gv);
-
-	s->arrow = XCreateFontCursor (dpy, XC_top_left_arrow);
 	s->place = XCreateFontCursor (dpy, XC_top_left_corner);
 	s->sweep = XCreateFontCursor (dpy, XC_bottom_right_corner);
 
-	attr.cursor = s->arrow;
-	attr.event_mask = SubstructureRedirectMask
-		| SubstructureNotifyMask | ColormapChangeMask | EnterWindowMask
-		| ButtonPressMask | ButtonReleaseMask | PropertyChangeMask;
-	mask = CWCursor|CWEventMask;
-
-	XChangeWindowAttributes(dpy, s->root, mask, &attr);
+	XSelectInput (dpy, s->root, SubstructureRedirectMask | SubstructureNotifyMask |
+				    ColormapChangeMask | PropertyChangeMask |
+				    ButtonPressMask | ButtonReleaseMask);
 
 	XSync(dpy, False);
 
@@ -322,11 +275,11 @@ void initscreen(ScreenInfo *s, int i)
 		s->notile_raised[t] = 0;
 	}
 
-	s->barwin = XCreateSimpleWindow(dpy, s->root, BAR_X(s), BAR_Y(s), BAR_WIDTH(s), BAR_HEIGHT, 1, s->black, s->white);
+	s->barwin = XCreateSimpleWindow(dpy, s->root, BAR_X(s), BAR_Y(s), BAR_WIDTH(s), BAR_HEIGHT, 0, s->black, s->white);
 	XSelectInput (dpy, s->barwin, ExposureMask | ButtonPressMask | ButtonReleaseMask);
 	raise_tbar (s);
-	s->tile_height = BAR_TOP(s);
-	s->res_height = BAR_TOP(s);
+	s->tile_height = BAR_Y(s);
+	s->res_height = BAR_Y(s);
 }
 
 ScreenInfo *getscreen(Window w)
