@@ -19,7 +19,7 @@ int manage(Client *c, int mapped)
 	XClassHint class;
 	XWMHints *hints;
 
-	XSelectInput(dpy, c->window, ColormapChangeMask | PropertyChangeMask | FocusChangeMask);
+	XSelectInput(dpy, c->window, ColormapChangeMask | PropertyChangeMask | EnterWindowMask | FocusChangeMask);
 
 	c->istool = 0;
 	c->issticky = 0;
@@ -50,6 +50,7 @@ int manage(Client *c, int mapped)
 	if (is_tool (c))
 	{
 		c->istool = 1;
+		c->isfloat = 1;
 		c->issticky = 1;
 		c->isnotile = 1;
 	}
@@ -68,11 +69,6 @@ int manage(Client *c, int mapped)
 	if (is_notile (c))
 	{
 		c->isnotile = 1;
-
-		if (prefs.sticky_notile)
-		{
-			c->issticky = 1;
-		}
 	}
 
 	c->input = hints ? hints->input : True;
@@ -297,15 +293,15 @@ void gravitate(Client *c, int invert)
 		break;
 	case SouthWestGravity:
 		dx = 0;
-		dy = 2*delta - (BAR_HEIGHT + 2);
+		dy = 2*delta - (BAR_HEIGHT);
 		break;
 	case SouthGravity:
 		dx = delta;
-		dy = 2*delta - (BAR_HEIGHT + 2);
+		dy = 2*delta - (BAR_HEIGHT);
 		break;
 	case SouthEastGravity:
 		dx = 2*delta;
-		dy = 2*delta - (BAR_HEIGHT + 2);
+		dy = 2*delta - (BAR_HEIGHT);
 		break;
 	default:
 		return;
