@@ -29,9 +29,6 @@ void set_defaults (void)
 
 	memset (&prefs, 0, sizeof (prefs));
 
-	prefs.border = 2;
-	prefs.tile_pad = 2;
-
 	for (i = 0; i < MAXSCREENS; i++)
 	{
 		for (j = 0; j < MAXDESKTOPS; j++)
@@ -216,6 +213,11 @@ char *show_mod (unsigned long mod)
 
 	r[0] = '\0';
 
+	if (!mod)
+	{
+		return "None";
+	}
+
 	if (mod & ShiftMask)
 	{
 		strcat (r, "Shift");
@@ -277,14 +279,6 @@ void dump_prefs (void)
 	printf ("! If you edit this, do not forget to uncomment any lines that you change.\n");
 	printf ("!\n");
 	printf ("!\n");
-	printf ("! Window border width: (0 - 128 pixels)\n");
-	printf ("!\n");
-	printf ("! larswm.border: %d\n", prefs.border);
-	printf ("!\n");
-	printf ("! How many pixels between windows: (0 - 128 pixels)\n");
-	printf ("!\n");
-	printf ("! larswm.tile_pad: %d\n", prefs.tile_pad);
-	printf ("!\n");
 	printf ("! Status bar and window border colors:\n");
 	printf ("!\n");
 	if (prefs.fgstr)
@@ -330,10 +324,6 @@ void dump_prefs (void)
 	printf ("!\n");
 	printf ("! larswm.?.?.clickthru: %s\n", show_bool (prefs.clickthru[0][0]));
 	printf ("!\n");
-	printf ("! Make all windows on the untiled subdesktop sticky by default?\n");
-	printf ("!\n");
-	printf ("! larswm.sticky_notile: %s\n", show_bool (prefs.sticky_notile));
-	printf ("!\n");
 
 	printf ("! Application commands for shortcuts:\n");
 	printf ("! Add one line for each application. Must have different numbers between 0 and %d.\n", MAXAPPS - 1);
@@ -514,9 +504,6 @@ unsigned long get_mod (char *s)
 	if (strstr (s, "mod4")    || strstr (s, "Mod4"))    m |= Mod4Mask;
 	if (strstr (s, "mod5")    || strstr (s, "Mod5"))    m |= Mod5Mask;
 
-	if (!m)
-		fprintf(stderr, "larswm: warning, key binding without modifier.\n");
-
 	return m;
 }
 
@@ -532,12 +519,6 @@ void validate_prefs (void)
 {
 	int i, j;
 
-	if (prefs.border < 0) prefs.border = 0;
-	if (prefs.border > 128) prefs.border = 128;
-
-	if (prefs.tile_pad < 0) prefs.tile_pad = 0;
-	if (prefs.tile_pad > 128) prefs.tile_pad = 128;
-
 	if (prefs.desktops < 1) prefs.desktops = 1;
 	if (prefs.desktops > MAXDESKTOPS) prefs.desktops = MAXDESKTOPS;
 
@@ -592,15 +573,6 @@ void load_prefs (char *filename)
 	if ((db = XrmGetFileDatabase (filename)) == NULL)
 		return;
 
-	if (XrmGetResource (db, "larswm.border", "Larswm.Border", &vt, &v))
-		prefs.border = atoi (v.addr);
-
-	if (XrmGetResource (db, "larswm.tile_pad", "Larswm.Tile_pad", &vt, &v))
-		prefs.tile_pad = atoi (v.addr);
-
-	if (XrmGetResource (db, "larswm.sticky_notile", "Larswm.Sticky_notile", &vt, &v))
-		prefs.sticky_notile = get_bool (v.addr);
-
 	if (XrmGetResource (db, "larswm.desktops", "Larswm.Desktops", &vt, &v))
 		prefs.desktops = atoi (v.addr);
 
