@@ -335,7 +335,7 @@ void find_tools (ScreenInfo *s)
 
 	if (found)
 	{
-		s->res_height = min_y - prefs.tile_pad;
+		s->res_height = min_y - TILE_PAD;
 
 		if (min_x < track_width[s->num][0]) t |= 1;
 		if (max_x >= track_x[s->num][1]) t |= 2;
@@ -502,17 +502,17 @@ void tile_all(ScreenInfo *s)
 			x = track_x[s->num][cur_track];
 			y = cur_pos * wh[cur_track];
 
-			width = track_width[s->num][cur_track] - (2 * BORDER) - prefs.tile_pad;
-			height = wh[cur_track] - (2 * BORDER) - prefs.tile_pad;
+			width = track_width[s->num][cur_track] - (2 * BORDER) - TILE_PAD;
+			height = wh[cur_track] - (2 * BORDER) - TILE_PAD;
 
 			if (cur_track == 1)
 			{
-				width += prefs.tile_pad;
+				width += TILE_PAD;
 			}
 
 			if ((cur_pos + 1) == cpt[cur_track])
 			{
-				height += prefs.tile_pad;
+				height += TILE_PAD;
 			}
 
 			if (c->size.flags & PResizeInc)
@@ -877,6 +877,7 @@ void next_window (ScreenInfo *s)
 
 void prev_screen (ScreenInfo *s)
 {
+	ScreenInfo *ns;
 	int cur;
 
 	if (!s)
@@ -889,11 +890,26 @@ void prev_screen (ScreenInfo *s)
 
 	raise_tbar (s);
 
-	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, &screens[cur]);
+	ns = &screens[cur];
+
+	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, ns);
+
+	if (!ns->notile_raised[ns->desktop] && ns->focused[ns->desktop])
+		active (ns->focused[ns->desktop]);
+	else if (ns->notile_raised[ns->desktop] && ns->notilefocused[ns->desktop])
+		active (ns->notilefocused[ns->desktop]);
+	else
+	{
+		revert_same (ns);
+
+		if (!current)
+			revert_window (ns);
+	}
 }
 
 void next_screen (ScreenInfo *s)
 {
+	ScreenInfo *ns;
 	int cur;
 
 	if (!s)
@@ -906,7 +922,21 @@ void next_screen (ScreenInfo *s)
 
 	raise_tbar (s);
 
-	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, &screens[cur]);
+	ns = &screens[cur];
+
+	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, ns);
+
+	if (!ns->notile_raised[ns->desktop] && ns->focused[ns->desktop])
+		active (ns->focused[ns->desktop]);
+	else if (ns->notile_raised[ns->desktop] && ns->notilefocused[ns->desktop])
+		active (ns->notilefocused[ns->desktop]);
+	else
+	{
+		revert_same (ns);
+
+		if (!current)
+			revert_window (ns);
+	}
 }
 
 ScreenInfo *mouse_on_screen (void)
@@ -1065,7 +1095,7 @@ void move_southwest (Client *c)
 	if (c && c->isnotile)
 	{
 		c->x = 0;
-		c->y = c->screen->tile_height - c->dy - BORDER - prefs.tile_pad;
+		c->y = c->screen->tile_height - c->dy - (2 * BORDER);
 		XMoveWindow (dpy, c->parent, c->x, c->y);
 		sendconfig (c);
 	}
@@ -1076,7 +1106,7 @@ void move_south (Client *c)
 	if (c && c->isnotile)
 	{
 		c->x = (DisplayWidth (dpy, c->screen->num) / 2) - (c->dx / 2) - BORDER;
-		c->y = c->screen->tile_height - c->dy - BORDER - prefs.tile_pad;
+		c->y = c->screen->tile_height - c->dy - (2 * BORDER);
 
 		if (c->x < 0)
 			c->x = 0;
@@ -1091,7 +1121,7 @@ void move_southeast (Client *c)
 	if (c && c->isnotile)
 	{
 		c->x = DisplayWidth (dpy, c->screen->num) - c->dx - (2 * BORDER);
-		c->y = c->screen->tile_height - c->dy - BORDER - prefs.tile_pad;
+		c->y = c->screen->tile_height - c->dy - (2 * BORDER);
 		XMoveWindow (dpy, c->parent, c->x, c->y);
 		sendconfig (c);
 	}
@@ -1118,7 +1148,7 @@ void move_down (Client *c)
 {
 	if (c && c->isnotile)
 	{
-		int max_y = c->screen->tile_height - c->dy - BORDER - prefs.tile_pad;
+		int max_y = c->screen->tile_height - c->dy - (2 * BORDER);
 
 		if (c->screen->bigmr[c->screen->desktop])
 			c->y += (c->screen->tile_height / 20);
